
from enum import Enum
class PrinterStatus(Enum): 
  CANCELLING = "CANCELLING"
  CLOSED_WITH_ERROR = "CLOSED_WITH_ERROR"
  CLOSED = "CLOSED"
  CONNECTING = "CONNECTING"
  DETECT_BAUDRATE = "DETECT_BAUDRATE"
  DETECT_SERIAL = "DETECT_SERIAL"
  ERROR = "ERROR"
  FINISHING = "FINISHING"
  RESERVED_NONE = "NONE"
  OFFLINE = "OFFLINE"
  OPEN_SERIAL = "OPEN_SERIAL"
  OPERATIONAL = "OPERATIONAL"
  PAUSED = "PAUSED"
  PAUSING = "PAUSING"
  PRINTING = "PRINTING"
  STARTING = "STARTING"
  TRANSFERING_FILE = "TRANSFERING_FILE"
  UNKNOWN = "UNKNOWN"